@@ -67,6 +67,7 @@ from redis.commands.search.result import Result
 
 from redisvl.exceptions import (
     QueryValidationError,
+    RedisModuleVersionError,
     RedisSearchError,
     RedisVLError,
     SchemaValidationError,
@@ -83,10 +84,14 @@ from redisvl.query.filter import FilterExpression
 from redisvl.redis.connection import (
     RedisConnectionFactory,
     convert_index_info_to_schema,
+    supports_svs,
+    supports_svs_async,
 )
+from redisvl.redis.constants import SVS_MIN_REDIS_VERSION
 from redisvl.schema import IndexSchema, StorageType
 from redisvl.schema.fields import (
     VECTOR_NORM_MAP,
+    SVSVectorField,
     VectorDistanceMetric,
     VectorIndexAlgorithm,
 )
@@ -228,6 +233,12 @@ class BaseSearchIndex:
             index_schema=self.schema
         )
 
+    def _uses_svs_vamana(self) -> bool:
+        """Check if schema contains any SVS-VAMANA vector fields."""
+        return any(
+            isinstance(field, SVSVectorField) for field in self.schema.fields.values()
+        )
+
     def _validate_query(self, query: BaseQuery) -> None:
         """Validate a query."""
         if isinstance(query, VectorQuery):
@@ -535,6 +546,15 @@ class SearchIndex(BaseSearchIndex):
         self.__redis_client = redis_client
         return self
 
+    def _check_svs_support(self) -> None:
+        """Validate SVS-VAMANA support.
+
+        Raises:
+            RedisModuleVersionError: If SVS-VAMANA requirements are not met.
+        """
+        if not supports_svs(self._redis_client):
+            raise RedisModuleVersionError.for_svs_vamana(SVS_MIN_REDIS_VERSION)
+
     def create(self, overwrite: bool = False, drop: bool = False) -> None:
         """Create an index in Redis with the current schema and properties.
 
@@ -566,6 +586,10 @@ class SearchIndex(BaseSearchIndex):
         if not isinstance(overwrite, bool):
             raise TypeError("overwrite must be of type bool")
 
+        # Check if schema uses SVS-VAMANA and validate Redis capabilities
+        if self._uses_svs_vamana():
+            self._check_svs_support()
+
         if self.exists():
             if not overwrite:
                 logger.info("Index already exists, not overwriting.")
@@ -1195,7 +1219,7 @@ class AsyncSearchIndex(BaseSearchIndex):
 
         if redis_url:
             redis_client = await RedisConnectionFactory._get_aredis_connection(
-                url=redis_url,
+                redis_url=redis_url,
                 **kwargs,
             )
         elif redis_client:
@@ -1254,7 +1278,7 @@ class AsyncSearchIndex(BaseSearchIndex):
                     # Pass lib_name to connection factory
                     kwargs = {**self._connection_kwargs}
                     if self._redis_url:
-                        kwargs["url"] = self._redis_url
+                        kwargs["redis_url"] = self._redis_url
                     if self._lib_name:
                         kwargs["lib_name"] = self._lib_name
                     self._redis_client = (
@@ -1302,6 +1326,16 @@ class AsyncSearchIndex(BaseSearchIndex):
                 f"Error while fetching {name} index info: {str(e)}"
             ) from e
 
+    async def _check_svs_support_async(self) -> None:
+        """Validate SVS-VAMANA support.
+
+        Raises:
+            RedisModuleVersionError: If SVS-VAMANA requirements are not met.
+        """
+        client = await self._get_client()
+        if not await supports_svs_async(client):
+            raise RedisModuleVersionError.for_svs_vamana(SVS_MIN_REDIS_VERSION)
+
     async def create(self, overwrite: bool = False, drop: bool = False) -> None:
         """Asynchronously create an index in Redis with the current schema
             and properties.
@@ -1335,6 +1369,10 @@ class AsyncSearchIndex(BaseSearchIndex):
         if not isinstance(overwrite, bool):
             raise TypeError("overwrite must be of type bool")
 
+        # Check if schema uses SVS-VAMANA and validate Redis capabilities
+        if self._uses_svs_vamana():
+            await self._check_svs_support_async()
+
         if await self.exists():
             if not overwrite:
                 logger.info("Index already exists, not overwriting.")
