@@ -1,4 +1,10 @@
-from redisvl.query.aggregate import AggregationQuery, HybridQuery
+from redisvl.query.aggregate import (
+    AggregateHybridQuery,
+    AggregationQuery,
+    HybridQuery,
+    MultiVectorQuery,
+    Vector,
+)
 from redisvl.query.query import (
     BaseQuery,
     BaseVectorQuery,
@@ -20,5 +26,8 @@ __all__ = [
     "CountQuery",
     "TextQuery",
     "AggregationQuery",
+    "AggregateHybridQuery",
     "HybridQuery",
+    "MultiVectorQuery",
+    "Vector",
 ]
