@@ -1,14 +1,43 @@
 """
-RedisVL Fields, FieldAttributes, and Enums
+RedisVL Schema Fields and Attributes
 
-Reference Redis search source documentation as needed: https://redis.io/commands/ft.create/
-Reference Redis vector search documentation as needed: https://redis.io/docs/interact/search-and-query/advanced-concepts/vectors/
+This module defines field types and their attributes for creating Redis search indices.
+
+Field Types:
+    - TextField: Full-text search with stemming, phonetic matching
+    - TagField: Exact-match categorical data (tags, categories, IDs)
+    - NumericField: Numeric values for range queries and sorting
+    - GeoField: Geographic coordinates for location-based search
+    - VectorField: Vector embeddings for semantic similarity search
+        - FlatVectorField: Exact search (100% recall)
+        - HNSWVectorField: Approximate nearest neighbor search (fast, high recall)
+        - SVSVectorField: Compressed vector search with memory savings
+
+Common Vector Field Attributes (all algorithms):
+    - dims: Number of dimensions in the vector (e.g., 768, 1536)
+    - algorithm: Indexing algorithm ('flat', 'hnsw', or 'svs-vamana')
+    - datatype: Float precision ('float16', 'float32', 'float64', 'bfloat16')
+        Note: SVS-VAMANA only supports 'float16' and 'float32'
+    - distance_metric: Similarity metric ('COSINE', 'L2', 'IP')
+    - initial_cap: Initial capacity hint for memory allocation (optional)
+    - index_missing: Allow searching for documents without this field (optional)
+
+Algorithm-Specific Parameters:
+    - FLAT: block_size (memory management for dynamic indices)
+    - HNSW: m, ef_construction, ef_runtime, epsilon (graph tuning)
+    - SVS-VAMANA: graph_max_degree, construction_window_size, search_window_size,
+                  compression, reduce, training_threshold (VAMANA graph algorithm
+                  with Intel hardware optimization and vector compression)
+
+References:
+    - Redis FT.CREATE: https://redis.io/commands/ft.create/
+    - Vector Search: https://redis.io/docs/interact/search-and-query/advanced-concepts/vectors/
 """
 
 from enum import Enum
 from typing import Any, Dict, Literal, Optional, Tuple, Type, Union
 
-from pydantic import BaseModel, Field, field_validator
+from pydantic import BaseModel, Field, field_validator, model_validator
 from redis.commands.search.field import Field as RedisField
 from redis.commands.search.field import GeoField as RedisGeoField
 from redis.commands.search.field import NumericField as RedisNumericField
@@ -16,8 +45,11 @@ from redis.commands.search.field import TagField as RedisTagField
 from redis.commands.search.field import TextField as RedisTextField
 from redis.commands.search.field import VectorField as RedisVectorField
 
+from redisvl.utils.log import get_logger
 from redisvl.utils.utils import norm_cosine_distance, norm_l2_distance
 
+logger = get_logger(__name__)
+
 VECTOR_NORM_MAP = {
     "COSINE": norm_cosine_distance,
     "L2": norm_l2_distance,
@@ -51,6 +83,18 @@ class VectorDataType(str, Enum):
 class VectorIndexAlgorithm(str, Enum):
     FLAT = "FLAT"
     HNSW = "HNSW"
+    SVS_VAMANA = "SVS-VAMANA"
+
+
+class CompressionType(str, Enum):
+    """Vector compression types for SVS-VAMANA algorithm"""
+
+    LVQ4 = "LVQ4"
+    LVQ4x4 = "LVQ4x4"
+    LVQ4x8 = "LVQ4x8"
+    LVQ8 = "LVQ8"
+    LeanVec4x8 = "LeanVec4x8"
+    LeanVec8x8 = "LeanVec8x8"
 
 
 ### Field Attributes ###
@@ -111,12 +155,12 @@ class GeoFieldAttributes(BaseFieldAttributes):
 
 
 class BaseVectorFieldAttributes(BaseModel):
-    """Base vector field attributes shared by both FLAT and HNSW fields"""
+    """Base vector field attributes shared by FLAT, HNSW, and SVS-VAMANA fields"""
 
     dims: int
     """Dimensionality of the vector embeddings field"""
     algorithm: VectorIndexAlgorithm
-    """The indexing algorithm for the field: HNSW or FLAT"""
+    """The indexing algorithm for the field: FLAT, HNSW, or SVS-VAMANA"""
     datatype: VectorDataType = Field(default=VectorDataType.FLOAT32)
     """The float datatype for the vector embeddings"""
     distance_metric: VectorDistanceMetric = Field(default=VectorDistanceMetric.COSINE)
@@ -148,27 +192,120 @@ class BaseVectorFieldAttributes(BaseModel):
 
 
 class FlatVectorFieldAttributes(BaseVectorFieldAttributes):
-    """FLAT vector field attributes"""
+    """FLAT vector field attributes for exact nearest neighbor search."""
 
     algorithm: Literal[VectorIndexAlgorithm.FLAT] = VectorIndexAlgorithm.FLAT
-    """The indexing algorithm for the vector field"""
+    """The indexing algorithm (fixed as 'flat')"""
+
     block_size: Optional[int] = None
-    """Block size to hold amount of vectors in a contiguous array. This is useful when the index is dynamic with respect to addition and deletion"""
+    """Block size for processing (optional) - improves batch operation throughput"""
 
 
 class HNSWVectorFieldAttributes(BaseVectorFieldAttributes):
-    """HNSW vector field attributes"""
+    """HNSW vector field attributes for approximate nearest neighbor search."""
 
     algorithm: Literal[VectorIndexAlgorithm.HNSW] = VectorIndexAlgorithm.HNSW
-    """The indexing algorithm for the vector field"""
+    """The indexing algorithm (fixed as 'hnsw')"""
     m: int = Field(default=16)
-    """Number of max outgoing edges for each graph node in each layer"""
+    """Max outgoing edges per node in each layer (default: 16, range: 8-64)"""
+
     ef_construction: int = Field(default=200)
-    """Number of max allowed potential outgoing edges candidates for each node in the graph during build time"""
+    """Max edge candidates during build time (default: 200, range: 100-800)"""
+
     ef_runtime: int = Field(default=10)
-    """Number of maximum top candidates to hold during KNN search"""
+    """Max top candidates during search (default: 10) - primary tuning parameter"""
+
     epsilon: float = Field(default=0.01)
-    """Relative factor that sets the boundaries in which a range query may search for candidates"""
+    """Range search boundary factor (default: 0.01)"""
+
+
+class SVSVectorFieldAttributes(BaseVectorFieldAttributes):
+    """SVS-VAMANA vector field attributes with compression support."""
+
+    algorithm: Literal[VectorIndexAlgorithm.SVS_VAMANA] = (
+        VectorIndexAlgorithm.SVS_VAMANA
+    )
+    """The indexing algorithm for the vector field"""
+
+    # Graph Construction Parameters
+    graph_max_degree: int = Field(default=40)
+    """Max edges per node (default: 40) - affects recall vs memory"""
+
+    construction_window_size: int = Field(default=250)
+    """Build-time candidates (default: 250) - affects quality vs build time"""
+
+    search_window_size: int = Field(default=20)
+    """Search candidates (default: 20) - primary tuning parameter"""
+
+    epsilon: float = Field(default=0.01)
+    """Range query boundary factor (default: 0.01)"""
+
+    # Compression Parameters
+    compression: Optional[CompressionType] = None
+    """Vector compression: LVQ4, LVQ8, LeanVec4x8, LeanVec8x8"""
+
+    reduce: Optional[int] = None
+    """Dimensionality reduction for LeanVec types (must be < dims)"""
+
+    training_threshold: Optional[int] = None
+    """Min vectors before compression training (default: 10,240)"""
+
+    @model_validator(mode="after")
+    def validate_svs_params(self):
+        """Validate SVS-VAMANA specific constraints"""
+        # Datatype validation: SVS only supports FLOAT16 and FLOAT32
+        if self.datatype not in (VectorDataType.FLOAT16, VectorDataType.FLOAT32):
+            raise ValueError(
+                f"SVS-VAMANA only supports FLOAT16 and FLOAT32 datatypes. "
+                f"Got: {self.datatype}. "
+                f"Unsupported types: BFLOAT16, FLOAT64, INT8, UINT8."
+            )
+
+        # Reduce validation: must be less than dims and only valid with LeanVec
+        if self.reduce is not None:
+            if self.reduce >= self.dims:
+                raise ValueError(
+                    f"reduce ({self.reduce}) must be less than dims ({self.dims})"
+                )
+
+            # Validate that reduce is only used with LeanVec compression
+            if self.compression is None:
+                raise ValueError(
+                    "reduce parameter requires compression to be set. "
+                    "Use LeanVec4x8 or LeanVec8x8 compression with reduce."
+                )
+
+            if not self.compression.value.startswith("LeanVec"):
+                raise ValueError(
+                    f"reduce parameter is only supported with LeanVec compression types. "
+                    f"Got compression={self.compression.value}. "
+                    f"Either use LeanVec4x8/LeanVec8x8 or remove the reduce parameter."
+                )
+
+        # LeanVec without reduce is not recommended
+        if (
+            self.compression
+            and self.compression.value.startswith("LeanVec")
+            and not self.reduce
+        ):
+            logger.warning(
+                f"LeanVec compression selected without 'reduce'. "
+                f"Consider setting reduce={self.dims//2} for better performance"
+            )
+
+        if self.graph_max_degree and self.graph_max_degree < 32:
+            logger.warning(
+                f"graph_max_degree={self.graph_max_degree} is low. "
+                f"Consider values between 32-64 for better recall."
+            )
+
+        if self.search_window_size and self.search_window_size > 100:
+            logger.warning(
+                f"search_window_size={self.search_window_size} is high. "
+                f"This may impact query latency. Consider values between 20-50."
+            )
+
+        return self
 
 
 ### Field Classes ###
@@ -352,7 +489,7 @@ class GeoField(BaseField):
 
 
 class FlatVectorField(BaseField):
-    "Vector field with a FLAT index (brute force nearest neighbors search)"
+    """Vector field with FLAT (exact search) indexing for exact nearest neighbor search."""
 
     type: Literal[FieldTypes.VECTOR] = FieldTypes.VECTOR
     attrs: FlatVectorFieldAttributes
@@ -367,7 +504,7 @@ class FlatVectorField(BaseField):
 
 
 class HNSWVectorField(BaseField):
-    """Vector field with an HNSW index (approximate nearest neighbors search)"""
+    """Vector field with HNSW (Hierarchical Navigable Small World) indexing for approximate nearest neighbor search."""
 
     type: Literal["vector"] = "vector"
     attrs: HNSWVectorFieldAttributes
@@ -387,6 +524,33 @@ class HNSWVectorField(BaseField):
         return RedisVectorField(name, self.attrs.algorithm, field_data, as_name=as_name)
 
 
+class SVSVectorField(BaseField):
+    """Vector field with SVS-VAMANA indexing and compression for memory-efficient approximate nearest neighbor search."""
+
+    type: Literal[FieldTypes.VECTOR] = FieldTypes.VECTOR
+    attrs: SVSVectorFieldAttributes
+
+    def as_redis_field(self) -> RedisField:
+        name, as_name = self._handle_names()
+        field_data = self.attrs.field_data
+        field_data.update(
+            {
+                "GRAPH_MAX_DEGREE": self.attrs.graph_max_degree,
+                "CONSTRUCTION_WINDOW_SIZE": self.attrs.construction_window_size,
+                "SEARCH_WINDOW_SIZE": self.attrs.search_window_size,
+                "EPSILON": self.attrs.epsilon,
+            }
+        )
+        # Add compression parameters if specified
+        if self.attrs.compression is not None:
+            field_data["COMPRESSION"] = self.attrs.compression
+        if self.attrs.reduce is not None:
+            field_data["REDUCE"] = self.attrs.reduce
+        if self.attrs.training_threshold is not None:
+            field_data["TRAINING_THRESHOLD"] = self.attrs.training_threshold
+        return RedisVectorField(name, self.attrs.algorithm, field_data, as_name=as_name)
+
+
 FIELD_TYPE_MAP = {
     "tag": TagField,
     "text": TextField,
@@ -397,6 +561,7 @@ FIELD_TYPE_MAP = {
 VECTOR_FIELD_TYPE_MAP = {
     "flat": FlatVectorField,
     "hnsw": HNSWVectorField,
+    "svs-vamana": SVSVectorField,
 }
 
 
